@@ -13,6 +13,7 @@
 ****************************************************/
 
 #include "xxx.h"
+#include <R_ext/Utils.h> //R_CheckUserInterrupt(void)
 #if defined(linux) || defined(__linux__)
    #define FOPEN fopen64
    #define FSEEK fseeko
@@ -70,7 +71,7 @@ void genMatr();
 
    //write to file outfs[4]: phi2(a,b), phi3(a,b,c), phi4(a,b,c,d) and phi22(a,b,c,d)
    void phicw(int* pedigree,int* nr,int* nc,int* id,int* nid, int* top, char** infs, char** outfs){
-         signal(SIGINT, &userInt);
+         //signal(SIGINT, &userInt);
          FILE* ifs[4];
          int i;
          if(top[0]!=-999) for(i=0; i<4; i++){
@@ -95,12 +96,12 @@ void genMatr();
             fclose(ifs[i]);
             remove(infs[i]);
          }
-         if(stopIt) {stopIt = 0; error(_("Exit without finish.\a\n"));}
+         R_CheckUserInterrupt();//if(stopIt) {stopIt = 0; error(_("Exit without finish.\a\n"));}
    }
 
    //store in idcf[,9]
    void phicr(int* pedigree,int* nr,int* nc,int* id,int* nid, int* top, char** infs, double* idcf,int* verbose){
-         signal(SIGINT, &userInt);
+         //signal(SIGINT, &userInt);
          int i;
          FILE* ifs[4];
          if(top[0]!=-999) for(i=0; i<4; i++){
@@ -117,7 +118,7 @@ void genMatr();
             fclose(ifs[i]);
             remove(infs[i]);
          }
-         if(stopIt) {stopIt = 0; error(_("Exit without finish.\a\n"));}
+         R_CheckUserInterrupt();//if(stopIt) {stopIt = 0; error(_("Exit without finish.\a\n"));}
    }
 
    void gen_Matrix(double* idcf, int* nr, int* nc, int* nn,
@@ -139,7 +140,7 @@ void idcoefw(int** ped,int nr,int* id,int nid, int* top, FILE** ifs, FILE** ofs)
    int i, j, k, l;
    for(i=0;i<nid;i++){
       for(j=0;j<=i;j++){
-         if(stopIt) return;
+         R_CheckUserInterrupt();//if(stopIt) return;
          buff = phi2(id[i],id[j],ped,top,ifs);
          frwsize = fwrite(&buff,sizeof(double),1,ofs[0]);
          if(frwsize!=1){
@@ -151,7 +152,7 @@ void idcoefw(int** ped,int nr,int* id,int nid, int* top, FILE** ifs, FILE** ofs)
    for(i=0;i<nid;i++){
       for(j=0;j<=i;j++){
          for(k=0;k<=j;k++){
-            if(stopIt) return;
+            R_CheckUserInterrupt();//if(stopIt) return;
             buff = phi3(id[i],id[j],id[k],ped,top,ifs);
             frwsize = fwrite(&buff,sizeof(double),1,ofs[1]);
             if(frwsize!=1){
@@ -165,7 +166,7 @@ void idcoefw(int** ped,int nr,int* id,int nid, int* top, FILE** ifs, FILE** ofs)
       for(j=0;j<=i;j++){
          for(k=0;k<=j;k++){
             for(l=0;l<=k;l++){
-               if(stopIt) return;
+               R_CheckUserInterrupt();//if(stopIt) return;
                buff = phi4(id[i],id[j],id[k],id[l],ped,top,ifs);
                frwsize = fwrite(&buff,sizeof(double),1,ofs[2]);
                if(frwsize!=1){
@@ -180,7 +181,7 @@ void idcoefw(int** ped,int nr,int* id,int nid, int* top, FILE** ifs, FILE** ofs)
       for(j=0;j<=i;j++){
          for(k=0;k<=i;k++){
             for(l=0;l<=k;l++){
-               if(stopIt) return;
+               R_CheckUserInterrupt();//if(stopIt) return;
                buff = phi22(id[i],id[j],id[k],id[l],ped,top,ifs);
                frwsize = fwrite(&buff,sizeof(double),1,ofs[3]);
                if(frwsize!=1){
@@ -204,7 +205,7 @@ void idcoefr(int** ped,int nr,int* id,int nid, int* top, FILE** ifs, double* idc
       if(verbose) Rprintf("."); //Rprintf("%d ",i+1);
       for(j=0;j<=i;j++){
 //         if(verbose) Rprintf(".");
-         if(stopIt) return;
+         R_CheckUserInterrupt();//if(stopIt) return;
 
          aa = 2.0*phi2(id[i],id[i],ped,top,ifs);
          bb = 2.0*phi2(id[j],id[j],ped,top,ifs);
